@@ -1,10 +1,11 @@
+from pathlib import Path
 from typing import List, Tuple
-from path import Path
+
 import cli_ui as ui
 
 import tbump.action
-from tbump.config import Config
 import tbump.git
+from tbump.config import Config
 
 
 class DirtyRepository(tbump.git.GitError):
@@ -56,8 +57,7 @@ class Command(tbump.action.Action):
         self.run()
 
     def run(self) -> None:
-        full_args = [self.repo_path] + self.cmd
-        return tbump.git.run_git(*full_args, verbose=False)
+        return tbump.git.run_git(self.repo_path, *self.cmd, verbose=False)
 
 
 class GitBumper:
@@ -69,17 +69,18 @@ class GitBumper:
         self.remote_branch = ""
         self.commands = []  # type: List[Command]
 
+    def get_tag_name(self, new_version: str) -> str:
+        return self.tag_template.format(new_version=new_version)
+
     def set_config(self, config: Config) -> None:
-        self.tag_template = config.tag_template
-        self.message_template = config.message_template
+        self.tag_template = config.git_tag_template
+        self.message_template = config.git_message_template
 
     def run_git(self, *args: str, verbose: bool = False) -> None:
-        full_args = [self.repo_path] + list(args)
-        return tbump.git.run_git(*full_args, verbose=verbose)
+        return tbump.git.run_git(self.repo_path, *args, verbose=verbose)
 
     def run_git_captured(self, *args: str, check: bool = True) -> Tuple[int, str]:
-        full_args = [self.repo_path] + list(args)
-        return tbump.git.run_git_captured(*full_args, check=check)
+        return tbump.git.run_git_captured(self.repo_path, *args, check=check)
 
     def check_dirty(self) -> None:
         _, out = self.run_git_captured("status", "--porcelain")
@@ -114,7 +115,7 @@ class GitBumper:
 
     def check_branch_state(self, new_version: str) -> None:
         self.get_current_branch()
-        tag_name = self.tag_template.format(new_version=new_version)
+        tag_name = self.get_tag_name(new_version)
         self.check_ref_does_not_exists(tag_name)
 
         tracking_ref = self.get_tracking_ref()
@@ -129,7 +130,7 @@ class GitBumper:
         self.add_command(res, "add", "--update")
         commit_message = self.message_template.format(new_version=new_version)
         self.add_command(res, "commit", "--message", commit_message)
-        tag_name = self.tag_template.format(new_version=new_version)
+        tag_name = self.get_tag_name(new_version)
         tag_message = tag_name
         self.add_command(res, "tag", "--annotate", "--message", tag_message, tag_name)
         self.add_command(res, "push", self.remote_name, self.remote_branch)
